@@ -30,7 +30,6 @@ class QWT_EXPORT QwtPointPolar
 public:
     QwtPointPolar();
     QwtPointPolar( double azimuth, double radius );
-    QwtPointPolar( const QwtPointPolar & );
     QwtPointPolar( const QPointF & );
 
     void setPoint( const QPointF & );
@@ -80,16 +79,6 @@ inline QwtPointPolar::QwtPointPolar( double azimuth, double radius ):
 {
 }
 
-/*!
-    Constructs a point using the values of the point specified.
-    \param other Other point
-*/
-inline QwtPointPolar::QwtPointPolar( const QwtPointPolar &other ):
-    d_azimuth( other.d_azimuth ),
-    d_radius( other.d_radius )
-{
-}
-
 //! Returns true if radius() >= 0.0
 inline bool QwtPointPolar::isValid() const
 {
